@@ -230,6 +230,10 @@ class BMC(object):
         """List SEL entries"""
         return self.handle.sel_list()
 
+    def sel_elist(self):
+        """Extended SEL list"""
+        return self.handle.sel_elist()
+
     def sel_clear(self):
         """Clear the SEL"""
         return self.handle.sel_clear()
@@ -393,10 +397,13 @@ class BMC(object):
     def user_priv(self, userid, priv_level, channel=None):
         return self.handle.user_priv(userid=userid, priv_level=priv_level,
                                      channel=channel)
-    #
-    # fabric commands
-    #
+    """Fabric commands
 
+    In pyipmi/fabric.py, these commands are mapped to classes that 
+    are subclasses of the Command class. Those subclasses contain the
+    string arguments that are run by pyipmi/ipmitool.py
+
+    """
     def fabric_update_config(self):
         return self.handle.fabric_updateconfig()
 
@@ -437,9 +444,19 @@ class BMC(object):
     def fabric_rm_macaddr(self, iface, macaddr, nodeid=None):
         return self.handle.fabric_rmmacaddr(nodeid=nodeid, iface=iface, macaddr=macaddr)
 
-    #
-    # fabric config commands
-    #
+    def fabric_get_uplink_speed(self):
+        return self.handle.fabric_getuplinkspeed()
+
+    def fabric_get_uplink_info(self):
+        return self.handle.fabric_getuplinkinfo()
+
+    """Fabric config commands
+
+    In pyipmi/fabric_config.py, these commands are mapped to classes that 
+    are subclasses of the Command class. Those subclasses contain the
+    string arguments that are run by pyipmi/ipmitool.py
+
+    """
 
     def fabric_config_update_config(self):
         return self.handle.fabric_config_updateconfig()
@@ -468,6 +485,9 @@ class BMC(object):
     def fabric_config_get_ip_addr_base(self):
         return self.handle.fabric_config_get_ipaddr_base()
 
+    def fabric_config_set_ipaddr_base(self, ipaddr):
+        return self.handle.fabric_config_set_ipaddr_base(ipaddr=ipaddr)
+
     def fabric_config_get_linkspeed(self):
         return self.handle.fabric_config_getlinkspeed()
 
@@ -504,6 +524,12 @@ class BMC(object):
     def fabric_config_get_macaddr_mask(self):
         return self.handle.fabric_config_get_macaddr_mask()
 
+    def fabric_config_set_netmask(self, netmask):
+        return self.handle.fabric_config_set_netmask(netmask=netmask)
+
+    def fabric_config_set_defgw(self, ipaddr):
+        return self.handle.fabric_config_set_defgw(ipaddr=ipaddr)
+
     def set_bootdev(self, device, options=None):
         return self.handle.bootdev_set(device=device, options=options)
 
@@ -554,6 +580,10 @@ class BMC(object):
         return self.handle.fabric_info_getdepthchart(filename=filename,
                                                      tftp_addr=tftp_addr)
 
+    def pmic_get_version(self):
+        return self.handle.pmic_get_version()
+
+
 class LanBMC(BMC):
     """A BMC that's accessed over the LAN"""
     def __init__(self,
